@@ -9,8 +9,7 @@ Copyright Contributors to the Zincware Project.
 Description: Standard python init file for the utils directory
 """
 
-from .utils import is_jsonable, cwd_temp_dir
-from .serializer import serializer, deserializer
 from .config import config
+from .utils import cwd_temp_dir, is_jsonable
 
-__all__ = ["is_jsonable", "serializer", "deserializer", "config", "cwd_temp_dir"]
+__all__ = ["is_jsonable", "config", "cwd_temp_dir"]
