@@ -10,12 +10,15 @@ Description:
 """
 
 import json
+import logging
 import os
 import shutil
 import tempfile
 
 from zntrack.utils.config import config
 
+log = logging.getLogger(__name__)
+
 
 # https://stackoverflow.com/questions/42033142/is-there-an-easy-way-to-check-if-an-object-is-json-serializable-in-python
 def is_jsonable(x: dict) -> bool:
@@ -55,7 +58,7 @@ def cwd_temp_dir(required_files=None) -> tempfile.TemporaryDirectory:
         The temporary  directory file. Close with temp_dir.cleanup() at the end.
 
     """
-    temp_dir = tempfile.TemporaryDirectory()
+    temp_dir = tempfile.TemporaryDirectory()  # add ignore_cleanup_errors=True in Py3.10?
 
     if config.nb_name is not None:
         shutil.copy(config.nb_name, temp_dir.name)
@@ -66,3 +69,19 @@ def cwd_temp_dir(required_files=None) -> tempfile.TemporaryDirectory:
     os.chdir(temp_dir.name)
 
     return temp_dir
+
+
+def deprecated(reason, version="v0.0.0"):
+    """Depreciation Warning"""
+
+    def decorator(func):
+        def wrapper(*args, **kwargs):
+            log.critical(
+                f"DeprecationWarning for {func.__name__}: {reason} (Deprecated since"
+                f" {version})"
+            )
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return decorator
